@@ -240,8 +240,7 @@ adw_carousel_indicator_dots_snapshot (GtkWidget   *widget,
   AdwCarouselIndicatorDots *self = ADW_CAROUSEL_INDICATOR_DOTS (widget);
   int i, n_points;
   double position;
-  g_autofree double *points = NULL;
-  g_autofree double *sizes = NULL;
+  double *points, *sizes;
 
   if (!self->carousel)
     return;
@@ -249,8 +248,11 @@ adw_carousel_indicator_dots_snapshot (GtkWidget   *widget,
   points = adw_swipeable_get_snap_points (ADW_SWIPEABLE (self->carousel), &n_points);
   position = adw_carousel_get_position (self->carousel);
 
-  if (n_points < 2)
+  if (n_points < 2) {
+    g_free (points);
+
     return;
+  }
 
   if (self->orientation == GTK_ORIENTATION_HORIZONTAL &&
       gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
@@ -263,6 +265,9 @@ adw_carousel_indicator_dots_snapshot (GtkWidget   *widget,
     sizes[i] = points[i] - points[i - 1];
 
   snapshot_dots (widget, snapshot, self->orientation, position, sizes, n_points);
+
+  g_free (sizes);
+  g_free (points);
 }
 
 static void
@@ -392,7 +397,7 @@ adw_carousel_indicator_dots_new (void)
 
 /**
  * adw_carousel_indicator_dots_get_carousel: (attributes org.gtk.Method.get_property=carousel)
- * @self: a `AdwCarouselIndicatorDots`
+ * @self: an indicator
  *
  * Gets the displayed carousel.
  *
@@ -410,7 +415,7 @@ adw_carousel_indicator_dots_get_carousel (AdwCarouselIndicatorDots *self)
 
 /**
  * adw_carousel_indicator_dots_set_carousel: (attributes org.gtk.Method.set_property=carousel)
- * @self: a `AdwCarouselIndicatorDots`
+ * @self: an indicator
  * @carousel: (nullable): a carousel
  *
  * Sets the displayed carousel.
