@@ -234,7 +234,7 @@ adw_clamp_layout_measure (GtkLayoutManager *manager,
       continue;
 
     if (self->orientation == orientation) {
-      gtk_widget_measure (child, orientation, -1,
+      gtk_widget_measure (child, orientation, for_size,
                           &child_min, &child_nat,
                           &child_min_baseline, &child_nat_baseline);
 
@@ -345,8 +345,10 @@ adw_clamp_layout_class_init (AdwClampLayoutClass *klass)
   /**
    * AdwClampLayout:maximum-size: (attributes org.gtk.Property.get=adw_clamp_layout_get_maximum_size org.gtk.Property.set=adw_clamp_layout_set_maximum_size)
    *
-   * The maximum size to allocate to the children. It is the width if the
-   * layout is horizontal, or the height if it is vertical.
+   * The maximum size to allocate to the children.
+   *
+   * It is the width if the layout is horizontal, or the height if it is
+   * vertical.
    *
    * Since: 1.0
    */
@@ -411,7 +413,7 @@ adw_clamp_layout_new (void)
 
 /**
  * adw_clamp_layout_get_maximum_size: (attributes org.gtk.Method.get_property=maximum-size)
- * @self: a `AdwClampLayout`
+ * @self: a clamp layout
  *
  * Gets the maximum size allocated to the children.
  *
@@ -429,7 +431,7 @@ adw_clamp_layout_get_maximum_size (AdwClampLayout *self)
 
 /**
  * adw_clamp_layout_set_maximum_size: (attributes org.gtk.Method.set_property=maximum-size)
- * @self: a `AdwClampLayout`
+ * @self: a clamp layout
  * @maximum_size: the maximum size
  *
  * Sets the maximum size allocated to the children.
@@ -454,7 +456,7 @@ adw_clamp_layout_set_maximum_size (AdwClampLayout *self,
 
 /**
  * adw_clamp_layout_get_tightening_threshold: (attributes org.gtk.Method.get_property=tightening-threshold)
- * @self: a `AdwClampLayout`
+ * @self: a clamp layout
  *
  * Gets the size above which the children are clamped.
  *
@@ -472,7 +474,7 @@ adw_clamp_layout_get_tightening_threshold (AdwClampLayout *self)
 
 /**
  * adw_clamp_layout_set_tightening_threshold: (attributes org.gtk.Method.set_property=tightening-threshold)
- * @self: a `AdwClampLayout`
+ * @self: a clamp layout
  * @tightening_threshold: the tightening threshold
  *
  * Sets the size above which the children are clamped.
