@@ -119,10 +119,13 @@ selection_changed (AdwComboRow *self)
 
   if (priv->use_subtitle) {
     if (g_list_model_get_n_items (G_LIST_MODEL (priv->current_selection)) > 0) {
-      g_autoptr (GtkListItem) item = g_list_model_get_item (G_LIST_MODEL (priv->current_selection), 0);
-      g_autofree char *repr = get_item_representation (self, item);
+      GtkListItem *item = g_list_model_get_item (G_LIST_MODEL (priv->current_selection), 0);
+      char *repr = get_item_representation (self, item);
 
       adw_action_row_set_subtitle (ADW_ACTION_ROW (self), repr);
+
+      g_free (repr);
+      g_object_unref (item);
     } else {
       adw_action_row_set_subtitle (ADW_ACTION_ROW (self), NULL);
     }
@@ -226,7 +229,7 @@ bind_item (GtkSignalListItemFactory *factory,
   gpointer item;
   GtkWidget *box;
   GtkWidget *icon;
-  g_autofree char *repr = NULL;
+  char *repr;
 
   item = gtk_list_item_get_item (list_item);
   box = gtk_list_item_get_child (list_item);
@@ -250,6 +253,8 @@ bind_item (GtkSignalListItemFactory *factory,
   } else {
     gtk_widget_hide (icon);
   }
+
+  g_clear_pointer (&repr, g_free);
 }
 
 static void
@@ -263,13 +268,15 @@ unbind_item (GtkSignalListItemFactory *factory,
 static void
 set_default_factory (AdwComboRow *self)
 {
-  g_autoptr (GtkListItemFactory) factory = gtk_signal_list_item_factory_new ();
+  GtkListItemFactory *factory = gtk_signal_list_item_factory_new ();
 
   g_signal_connect (factory, "setup", G_CALLBACK (setup_item), self);
   g_signal_connect (factory, "bind", G_CALLBACK (bind_item), self);
   g_signal_connect (factory, "unbind", G_CALLBACK (unbind_item), self);
 
   adw_combo_row_set_factory (self, factory);
+
+  g_object_unref (factory);
 }
 
 static void
@@ -563,7 +570,7 @@ adw_combo_row_new (void)
 
 /**
  * adw_combo_row_set_selected: (attributes org.gtk.Method.set_property=selected)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  * @position: the position of the item to select, or
  *   [const@Gtk.INVALID_LIST_POSITION]
  *
@@ -592,7 +599,7 @@ adw_combo_row_set_selected (AdwComboRow *self,
 
 /**
  * adw_combo_row_get_selected: (attributes org.gtk.Method.get_property=selected)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets the position of the selected item.
  *
@@ -618,7 +625,7 @@ adw_combo_row_get_selected (AdwComboRow *self)
 
 /**
  * adw_combo_row_get_selected_item: (attributes org.gtk.Method.get_property=selected-item)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets the selected item.
  *
@@ -643,7 +650,7 @@ adw_combo_row_get_selected_item (AdwComboRow *self)
 
 /**
  * adw_combo_row_get_model: (attributes org.gtk.Method.get_property=model)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets the model that provides the displayed items.
  *
@@ -665,7 +672,7 @@ adw_combo_row_get_model (AdwComboRow *self)
 
 /**
  * adw_combo_row_set_model: (attributes org.gtk.Method.set_property=model)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  * @model: (nullable) (transfer none): the model to use
  *
  * Sets the [iface@Gio.ListModel] to use.
@@ -729,7 +736,7 @@ adw_combo_row_set_model (AdwComboRow *self,
 
 /**
  * adw_combo_row_get_factory: (attributes org.gtk.Method.get_property=factory)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets the factory that's currently used to populate list items.
  *
@@ -751,7 +758,7 @@ adw_combo_row_get_factory (AdwComboRow *self)
 
 /**
  * adw_combo_row_set_factory: (attributes org.gtk.Method.set_property=factory)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  * @factory: (nullable) (transfer none): the factory to use
  *
  * Sets the `GtkListItemFactory` to use for populating list items.
@@ -782,7 +789,7 @@ adw_combo_row_set_factory (AdwComboRow        *self,
 
 /**
  * adw_combo_row_get_list_factory: (attributes org.gtk.Method.get_property=list-factory)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets the factory that's currently used to populate list items in the popup.
  *
@@ -804,7 +811,7 @@ adw_combo_row_get_list_factory (AdwComboRow *self)
 
 /**
  * adw_combo_row_set_list_factory: (attributes org.gtk.Method.set_property=list-factory)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  * @factory: (nullable) (transfer none): the factory to use
  *
  * Sets the `GtkListItemFactory` to use for populating list items in the popup.
@@ -835,7 +842,7 @@ adw_combo_row_set_list_factory (AdwComboRow        *self,
 
 /**
  * adw_combo_row_get_expression: (attributes org.gtk.Method.get_property=expression)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets the expression used to obtain strings from items.
  *
@@ -857,7 +864,7 @@ adw_combo_row_get_expression (AdwComboRow *self)
 
 /**
  * adw_combo_row_set_expression: (attributes org.gtk.Method.set_property=expression)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  * @expression: (nullable): an expression
  *
  * Sets the expression used to obtain strings from items.
@@ -894,7 +901,7 @@ adw_combo_row_set_expression (AdwComboRow   *self,
 
 /**
  * adw_combo_row_get_use_subtitle: (attributes org.gtk.Method.get_property=use-subtitle)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  *
  * Gets whether to use the current value as the subtitle.
  *
@@ -916,7 +923,7 @@ adw_combo_row_get_use_subtitle (AdwComboRow *self)
 
 /**
  * adw_combo_row_set_use_subtitle: (attributes org.gtk.Method.set_property=use-subtitle)
- * @self: a `AdwComboRow`
+ * @self: a combo row
  * @use_subtitle: whether to use the current value as the subtitle
  *
  * Sets whether to use the current value as the subtitle.
