@@ -15,6 +15,10 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
+#ifdef __APPLE__
+# include <AppKit/AppKit.h>
+#endif
+
 #define PORTAL_BUS_NAME "org.freedesktop.portal.Desktop"
 #define PORTAL_OBJECT_PATH "/org/freedesktop/portal/desktop"
 #define PORTAL_SETTINGS_INTERFACE "org.freedesktop.portal.Settings"
@@ -84,6 +88,7 @@ set_high_contrast (AdwSettings *self,
 
 /* Settings portal */
 
+#if defined(G_OS_UNIX) && !defined(__APPLE__)
 static gboolean
 get_disable_portal (void)
 {
@@ -99,11 +104,11 @@ read_portal_setting (AdwSettings  *self,
                      const char   *type,
                      GVariant    **out)
 {
-  g_autoptr (GError) error = NULL;
-  g_autoptr (GVariant) ret = NULL;
-  g_autoptr (GVariant) child = NULL;
-  g_autoptr (GVariant) child2 = NULL;
-  g_autoptr (GVariantType) out_type = NULL;
+  GError *error = NULL;
+  GVariant *ret;
+  GVariant *child, *child2;
+  GVariantType *out_type;
+  gboolean result = FALSE;
 
   ret = g_dbus_proxy_call_sync (self->settings_portal,
                                 "Read",
@@ -116,28 +121,21 @@ read_portal_setting (AdwSettings  *self,
     if (error->domain == G_DBUS_ERROR &&
         error->code == G_DBUS_ERROR_SERVICE_UNKNOWN) {
       g_debug ("Portal not found: %s", error->message);
-
-      return FALSE;
-    }
-
-    if (error->domain == G_DBUS_ERROR &&
-        error->code == G_DBUS_ERROR_UNKNOWN_METHOD) {
+    } else if (error->domain == G_DBUS_ERROR &&
+               error->code == G_DBUS_ERROR_UNKNOWN_METHOD) {
       g_debug ("Portal doesn't provide settings: %s", error->message);
-
-      return FALSE;
-    }
-
-    if (g_dbus_error_is_remote_error (error)) {
-      g_autofree char *remote_error = g_dbus_error_get_remote_error (error);
+    } else if (g_dbus_error_is_remote_error (error)) {
+      char *remote_error = g_dbus_error_get_remote_error (error);
 
       if (!g_strcmp0 (remote_error, PORTAL_ERROR_NOT_FOUND)) {
         g_debug ("Setting %s.%s of type %s not found", schema, name, type);
-
-        return FALSE;
       }
+      g_free (remote_error);
+    } else {
+      g_critical ("Couldn't read the %s setting: %s", name, error->message);
     }
 
-    g_critical ("Couldn't read the %s setting: %s", name, error->message);
+    g_clear_error (&error);
 
     return FALSE;
   }
@@ -146,16 +144,23 @@ read_portal_setting (AdwSettings  *self,
   g_variant_get (child, "v", &child2);
 
   out_type = g_variant_type_new (type);
-  if (!g_variant_type_equal (g_variant_get_type (child2), out_type)) {
+  if (g_variant_type_equal (g_variant_get_type (child2), out_type)) {
+    *out = child2;
+
+    result = TRUE;
+  } else {
     g_critical ("Invalid type for %s.%s: expected %s, got %s",
                 schema, name, type, g_variant_get_type_string (child2));
 
-    return FALSE;
+    g_variant_unref (child2);
   }
 
-  *out = g_steal_pointer (&child2);
+  g_variant_type_free (out_type);
+  g_variant_unref (child);
+  g_variant_unref (ret);
+  g_clear_error (&error);
 
-  return TRUE;
+  return result;
 }
 
 static AdwSystemColorScheme
@@ -200,7 +205,7 @@ settings_portal_changed_cb (GDBusProxy  *proxy,
 {
   const char *namespace;
   const char *name;
-  g_autoptr (GVariant) value = NULL;
+  GVariant *value = NULL;
 
   if (g_strcmp0 (signal_name, "SettingChanged"))
     return;
@@ -212,6 +217,8 @@ settings_portal_changed_cb (GDBusProxy  *proxy,
       self->color_scheme_use_fdo_setting) {
     set_color_scheme (self, get_fdo_color_scheme (value));
 
+    g_variant_unref (value);
+
     return;
   }
 
@@ -220,13 +227,17 @@ settings_portal_changed_cb (GDBusProxy  *proxy,
       !self->color_scheme_use_fdo_setting) {
     set_color_scheme (self, get_gnome_color_scheme (value));
 
+    g_variant_unref (value);
+
     return;
   }
 
-  if (!g_strcmp0 (namespace, "org.gnome.desktop.a11y.interface") &&
+  if (!g_strcmp0 (namespace, "org.gnome.desktop.interface.a11y") &&
       !g_strcmp0 (name, "high-contrast")) {
     set_high_contrast (self, g_variant_get_boolean (value));
 
+    g_variant_unref (value);
+
     return;
   }
 }
@@ -234,9 +245,8 @@ settings_portal_changed_cb (GDBusProxy  *proxy,
 static void
 init_portal (AdwSettings *self)
 {
-  g_autoptr (GError) error = NULL;
-  g_autoptr (GVariant) color_scheme_variant = NULL;
-  g_autoptr (GVariant) high_contrast_variant = NULL;
+  GError *error = NULL;
+  GVariant *variant;
 
   if (get_disable_portal ())
     return;
@@ -252,27 +262,35 @@ init_portal (AdwSettings *self)
   if (error) {
     g_debug ("Settings portal not found: %s", error->message);
 
+    g_error_free (error);
+
     return;
   }
 
   if (read_portal_setting (self, "org.freedesktop.appearance",
-                           "color-scheme", "u", &color_scheme_variant)) {
+                           "color-scheme", "u", &variant)) {
     self->has_color_scheme = TRUE;
     self->color_scheme_use_fdo_setting = TRUE;
-    self->color_scheme = get_fdo_color_scheme (color_scheme_variant);
+    self->color_scheme = get_fdo_color_scheme (variant);
+
+    g_variant_unref (variant);
   }
 
   if (!self->has_color_scheme &&
       read_portal_setting (self, "org.gnome.desktop.interface",
-                           "color-scheme", "s", &color_scheme_variant)) {
+                           "color-scheme", "s", &variant)) {
     self->has_color_scheme = TRUE;
-    self->color_scheme = get_gnome_color_scheme (color_scheme_variant);
+    self->color_scheme = get_gnome_color_scheme (variant);
+
+    g_variant_unref (variant);
   }
 
-  if (read_portal_setting (self, "org.gnome.desktop.a11y.interface",
-                           "high-contrast", "b", &high_contrast_variant)) {
+  if (read_portal_setting (self, "org.gnome.desktop.interface.a11y",
+                           "high-contrast", "b", &variant)) {
     self->has_high_contrast = TRUE;
-    self->high_contrast = g_variant_get_boolean (high_contrast_variant);
+    self->high_contrast = g_variant_get_boolean (variant);
+
+    g_variant_unref (variant);
   }
 
   if (!self->has_color_scheme && !self->has_high_contrast)
@@ -281,14 +299,96 @@ init_portal (AdwSettings *self)
   g_signal_connect (self->settings_portal, "g-signal",
                     G_CALLBACK (settings_portal_changed_cb), self);
 }
+#endif
+
+#ifdef __APPLE__
+@interface ThemeChangedObserver : NSObject
+{
+  AdwSettings *settings;
+}
+@end
+
+@implementation ThemeChangedObserver
+
+-(instancetype)initWithSettings:(AdwSettings *)_settings
+{
+  [self init];
+  g_set_weak_pointer (&self->settings, _settings);
+  return self;
+}
+
+-(void)dealloc
+{
+  g_clear_weak_pointer (&self->settings);
+  [super dealloc];
+}
+
+static AdwSystemColorScheme
+get_ns_color_scheme (void)
+{
+  if (@available(*, macOS 10.14)) {
+    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
+    NSString *style = [userDefaults stringForKey:@"AppleInterfaceStyle"];
+    BOOL isDark = [style isEqualToString:@"Dark"];
+#if 0
+    BOOL isAuto = [userDefaults boolForKey:@"AppleInterfaceStyleSwitchesAutomatically"];
+    BOOL isHighContrast = NO;
+
+    /* We can get HighContrast using [NSAppearance currentAppearance] and
+     * checking for the variants with HighContrast in their name, however
+     * those do not update when the notifications come in (or ever it
+     * seems unless a NSView changes them while drawing. If we can monitor
+     * a NSView, we could watch for effectiveAppearance changes.
+     */
+#endif
+
+    [style release];
+
+    return isDark ?
+      ADW_SYSTEM_COLOR_SCHEME_PREFER_DARK :
+      ADW_SYSTEM_COLOR_SCHEME_DEFAULT;
+  }
+
+  return ADW_SYSTEM_COLOR_SCHEME_DEFAULT;
+}
+
+-(void)appDidChangeTheme:(NSNotification *)notification
+{
+  if (self->settings != NULL)
+    set_color_scheme (self->settings, get_ns_color_scheme ());
+}
+@end
+
+static void
+init_nsapp_observer (AdwSettings *settings)
+{
+  static ThemeChangedObserver *observer;
+
+  if (@available(*, macOS 10.14)) {
+    settings->has_color_scheme = TRUE;
+  }
+
+  observer = [[ThemeChangedObserver alloc] initWithSettings:settings];
+
+  [[NSDistributedNotificationCenter defaultCenter]
+    addObserver:observer
+       selector:@selector(appDidChangeTheme:)
+           name:@"AppleInterfaceThemeChangedNotification"
+         object:nil];
+
+  [observer appDidChangeTheme:nil];
+}
+#endif
 
 /* GSettings */
 
+#ifndef G_OS_WIN32
 static gboolean
 is_running_in_flatpak (void)
 {
   return g_file_test ("/.flatpak-info", G_FILE_TEST_EXISTS);
 }
+#endif
 
 static void
 gsettings_color_scheme_changed_cb (AdwSettings *self)
@@ -306,13 +406,14 @@ static void
 init_gsettings (AdwSettings *self)
 {
   GSettingsSchemaSource *source;
-  g_autoptr (GSettingsSchema) schema = NULL;
-  g_autoptr (GSettingsSchema) a11y_schema = NULL;
+  GSettingsSchema *schema;
 
+#ifndef G_OS_WIN32
   /* While we can access gsettings in flatpak, we can't do anything useful with
    * them as they aren't propagated from the system. */
   if (is_running_in_flatpak ())
     return;
+#endif
 
   source = g_settings_schema_source_get_default ();
 
@@ -330,10 +431,12 @@ init_gsettings (AdwSettings *self)
                               self);
   }
 
-  a11y_schema = g_settings_schema_source_lookup (source, "org.gnome.desktop.a11y.interface", TRUE);
-  if (a11y_schema &&
+  g_clear_pointer (&schema, g_settings_schema_unref);
+
+  schema = g_settings_schema_source_lookup (source, "org.gnome.desktop.a11y.interface", TRUE);
+  if (schema &&
       !self->has_high_contrast &&
-      g_settings_schema_has_key (a11y_schema, "high-contrast")) {
+      g_settings_schema_has_key (schema, "high-contrast")) {
     self->has_high_contrast = TRUE;
     self->a11y_settings = g_settings_new ("org.gnome.desktop.a11y.interface");
     self->high_contrast = g_settings_get_boolean (self->a11y_settings, "high-contrast");
@@ -343,6 +446,8 @@ init_gsettings (AdwSettings *self)
                               G_CALLBACK (gsettings_high_contrast_changed_cb),
                               self);
   }
+
+  g_clear_pointer (&schema, g_settings_schema_unref);
 }
 
 /* Legacy */
@@ -350,8 +455,9 @@ init_gsettings (AdwSettings *self)
 static gboolean
 is_theme_high_contrast (GdkDisplay *display)
 {
-  g_auto (GValue) value = G_VALUE_INIT;
+  GValue value = G_VALUE_INIT;
   const char *theme_name;
+  gboolean ret;
 
   g_value_init (&value, G_TYPE_STRING);
   if (!gdk_display_get_setting (display, "gtk-theme-name", &value))
@@ -359,8 +465,12 @@ is_theme_high_contrast (GdkDisplay *display)
 
   theme_name = g_value_get_string (&value);
 
-  return !g_strcmp0 (theme_name, "HighContrast") ||
-         !g_strcmp0 (theme_name, "HighContrastInverse");
+  ret = !g_strcmp0 (theme_name, "HighContrast") ||
+        !g_strcmp0 (theme_name, "HighContrastInverse");
+
+  g_value_unset (&value);
+
+  return ret;
 }
 
 static void
@@ -396,7 +506,11 @@ adw_settings_constructed (GObject *object)
 
   G_OBJECT_CLASS (adw_settings_parent_class)->constructed (object);
 
+#ifdef __APPLE__
+  init_nsapp_observer (self);
+#elif defined(G_OS_UNIX)
   init_portal (self);
+#endif
 
   if (!self->has_color_scheme || !self->has_high_contrast)
     init_gsettings (self);
