@@ -61,6 +61,7 @@ struct _AdwStyleManager
   gboolean dark;
   gboolean setting_dark;
 
+  GtkCssProvider *animations_provider;
   guint animation_timeout_id;
 };
 
@@ -95,7 +96,7 @@ warn_prefer_dark_theme (AdwStyleManager *self)
 static void
 unregister_display (GdkDisplay *display)
 {
-  g_assert (g_hash_table_contains (display_style_managers, display));
+  g_assert (!g_hash_table_contains (display_style_managers, display));
 
   g_hash_table_remove (display_style_managers, display);
 }
@@ -123,8 +124,8 @@ register_display (GdkDisplayManager *display_manager,
 static gboolean
 enable_animations_cb (AdwStyleManager *self)
 {
-  gtk_settings_reset_property (gtk_settings_get_for_display (self->display),
-                               "gtk-enable-animations");
+  gtk_style_context_remove_provider_for_display (self->display,
+                                                 GTK_STYLE_PROVIDER (self->animations_provider));
 
   self->animation_timeout_id = 0;
 
@@ -135,24 +136,18 @@ static void
 update_stylesheet (AdwStyleManager *self)
 {
   GtkSettings *gtk_settings;
-  gboolean enable_animations;
 
   if (!self->display)
     return;
 
   gtk_settings = gtk_settings_get_for_display (self->display);
 
-  if (self->animation_timeout_id) {
+  if (self->animation_timeout_id)
     g_clear_handle_id (&self->animation_timeout_id, g_source_remove);
-    enable_animations = TRUE;
-  } else {
-    g_object_get (gtk_settings,
-                  "gtk-enable-animations", &enable_animations,
-                  NULL);
-  }
 
-  if (enable_animations)
-    g_object_set (gtk_settings, "gtk-enable-animations", FALSE, NULL);
+  gtk_style_context_add_provider_for_display (self->display,
+                                              GTK_STYLE_PROVIDER (self->animations_provider),
+                                              10000);
 
   self->setting_dark = TRUE;
 
@@ -180,12 +175,10 @@ update_stylesheet (AdwStyleManager *self)
                                            "/org/gnome/Adwaita/styles/defaults-light.css");
   }
 
-  if (enable_animations) {
-    self->animation_timeout_id =
-      g_timeout_add (SWITCH_DURATION,
-                     G_SOURCE_FUNC (enable_animations_cb),
-                     self);
-  }
+  self->animation_timeout_id =
+    g_timeout_add (SWITCH_DURATION,
+                   G_SOURCE_FUNC (enable_animations_cb),
+                   self);
 }
 
 static gboolean
@@ -279,6 +272,11 @@ adw_style_manager_constructed (GObject *object)
                                                   GTK_STYLE_PROVIDER (self->colors_provider),
                                                   GTK_STYLE_PROVIDER_PRIORITY_THEME);
     }
+
+    self->animations_provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (self->animations_provider,
+                                     "* { transition: none; }",
+                                     -1);
   }
 
   self->settings = adw_settings_get_default ();
@@ -311,6 +309,7 @@ adw_style_manager_dispose (GObject *object)
   g_clear_handle_id (&self->animation_timeout_id, g_source_remove);
   g_clear_object (&self->provider);
   g_clear_object (&self->colors_provider);
+  g_clear_object (&self->animations_provider);
 
   G_OBJECT_CLASS (adw_style_manager_parent_class)->dispose (object);
 }
@@ -509,7 +508,7 @@ void
 adw_style_manager_ensure (void)
 {
   GdkDisplayManager *display_manager = gdk_display_manager_get ();
-  g_autoptr (GSList) displays = NULL;
+  GSList *displays;
   GSList *l;
 
   if (display_style_managers)
@@ -530,6 +529,8 @@ adw_style_manager_ensure (void)
                     "display-opened",
                     G_CALLBACK (register_display),
                     NULL);
+
+  g_slist_free (displays);
 }
 
 /**
@@ -585,7 +586,7 @@ adw_style_manager_get_for_display (GdkDisplay *display)
 
 /**
  * adw_style_manager_get_display: (attributes org.gtk.Method.get_property=display)
- * @self: a `AdwStyleManager`
+ * @self: a style manager
  *
  * Gets the display the style manager is associated with.
  *
@@ -606,7 +607,7 @@ adw_style_manager_get_display (AdwStyleManager *self)
 
 /**
  * adw_style_manager_get_color_scheme: (attributes org.gtk.Method.get_property=color-scheme)
- * @self: a `AdwStyleManager`
+ * @self: a style manager
  *
  * Gets the requested application color scheme.
  *
@@ -624,7 +625,7 @@ adw_style_manager_get_color_scheme (AdwStyleManager *self)
 
 /**
  * adw_style_manager_set_color_scheme: (attributes org.gtk.Method.set_property=color-scheme)
- * @self: a `AdwStyleManager`
+ * @self: a style manager
  * @color_scheme: the color scheme
  *
  * Sets the requested application color scheme.
@@ -669,7 +670,7 @@ adw_style_manager_set_color_scheme (AdwStyleManager *self,
 
 /**
  * adw_style_manager_get_system_supports_color_schemes: (attributes org.gtk.Method.get_property=system-supports-color-schemes)
- * @self: a `AdwStyleManager`
+ * @self: a style manager
  *
  * Gets whether the system supports color schemes.
  *
@@ -687,7 +688,7 @@ adw_style_manager_get_system_supports_color_schemes (AdwStyleManager *self)
 
 /**
  * adw_style_manager_get_dark: (attributes org.gtk.Method.get_property=dark)
- * @self: a `AdwStyleManager`
+ * @self: a style manager
  *
  * Gets whether the application is using dark appearance.
  *
@@ -705,7 +706,7 @@ adw_style_manager_get_dark (AdwStyleManager *self)
 
 /**
  * adw_style_manager_get_high_contrast: (attributes org.gtk.Method.get_property=high-contrast)
- * @self: a `AdwStyleManager`
+ * @self: a style manager
  *
  * Gets whether the application is using high contrast appearance.
  *
