@@ -15,6 +15,7 @@
 #define TOUCHPAD_BASE_DISTANCE_H 400
 #define TOUCHPAD_BASE_DISTANCE_V 300
 #define EVENT_HISTORY_THRESHOLD_MS 150
+#define SCROLL_MULTIPLIER 10
 #define MIN_ANIMATION_DURATION 100
 #define MAX_ANIMATION_DURATION 400
 #define VELOCITY_THRESHOLD_TOUCH 0.3
@@ -28,12 +29,6 @@
 #define DRAG_THRESHOLD_DISTANCE 16
 #define EPSILON 0.005
 
-#if GTK_CHECK_VERSION (4, 7, 0)
-#define SCROLL_MULTIPLIER 1
-#else
-#define SCROLL_MULTIPLIER 10
-#endif
-
 #define SIGN(x) ((x) > 0.0 ? 1.0 : ((x) < 0.0 ? -1.0 : 0.0))
 
 /**
@@ -174,13 +169,15 @@ get_range (AdwSwipeTracker *self,
            double          *first,
            double          *last)
 {
-  g_autofree double *points = NULL;
+  double *points;
   int n;
 
   points = adw_swipeable_get_snap_points (self->swipeable, &n);
 
   *first = points[0];
   *last = points[n - 1];
+
+  g_free (points);
 }
 
 static void
@@ -360,11 +357,13 @@ gesture_update (AdwSwipeTracker *self,
     return;
 
   if (!self->allow_long_swipes) {
-    g_autofree double *points = NULL;
+    double *points;
     int n;
 
     points = adw_swipeable_get_snap_points (self->swipeable, &n);
     get_bounds (self, points, n, self->initial_progress, &lower, &upper);
+
+    g_free (points);
   } else {
     get_range (self, &lower, &upper);
   }
@@ -383,7 +382,7 @@ get_end_progress (AdwSwipeTracker *self,
                   gboolean         is_touchpad)
 {
   double pos, decel, slope;
-  g_autofree double *points = NULL;
+  double *points;
   int n;
   double lower, upper;
 
@@ -392,8 +391,13 @@ get_end_progress (AdwSwipeTracker *self,
 
   points = adw_swipeable_get_snap_points (self->swipeable, &n);
 
-  if (ABS (velocity) < (is_touchpad ? VELOCITY_THRESHOLD_TOUCHPAD : VELOCITY_THRESHOLD_TOUCH))
-    return points[find_closest_point (points, n, self->progress)];
+  if (ABS (velocity) < (is_touchpad ? VELOCITY_THRESHOLD_TOUCHPAD : VELOCITY_THRESHOLD_TOUCH)) {
+    pos = points[find_closest_point (points, n, self->progress)];
+
+    g_free (points);
+
+    return pos;
+  }
 
   decel = is_touchpad ? DECELERATION_TOUCHPAD : DECELERATION_TOUCH;
   slope = decel / (1.0 - decel) / 1000.0;
@@ -411,16 +415,16 @@ get_end_progress (AdwSwipeTracker *self,
 
   pos = (pos * SIGN (velocity)) + self->progress;
 
-  if (!self->allow_long_swipes) {
-
+  if (!self->allow_long_swipes)
     get_bounds (self, points, n, self->initial_progress, &lower, &upper);
-  } else {
+  else
     get_range (self, &lower, &upper);
-  }
 
   pos = CLAMP (pos, lower, upper);
   pos = points[find_point_for_projection (self, points, n, pos, velocity)];
 
+  g_free (points);
+
   return pos;
 }
 
@@ -666,9 +670,6 @@ handle_scroll_event (AdwSwipeTracker *self,
   is_vertical = (self->orientation == GTK_ORIENTATION_VERTICAL);
   distance = is_vertical ? TOUCHPAD_BASE_DISTANCE_V : TOUCHPAD_BASE_DISTANCE_H;
 
-  if (!event || gdk_event_get_event_type (event) != GDK_SCROLL)
-    return GDK_EVENT_PROPAGATE;
-
   if (gdk_scroll_event_get_direction (event) != GDK_SCROLL_SMOOTH)
     return GDK_EVENT_PROPAGATE;
 
@@ -913,16 +914,6 @@ adw_swipe_tracker_dispose (GObject *object)
   G_OBJECT_CLASS (adw_swipe_tracker_parent_class)->dispose (object);
 }
 
-static void
-adw_swipe_tracker_finalize (GObject *object)
-{
-  AdwSwipeTracker *self = ADW_SWIPE_TRACKER (object);
-
-  g_array_free (self->event_history, TRUE);
-
-  G_OBJECT_CLASS (adw_swipe_tracker_parent_class)->finalize (object);
-}
-
 static void
 adw_swipe_tracker_get_property (GObject    *object,
                                 guint       prop_id,
@@ -1006,7 +997,6 @@ adw_swipe_tracker_class_init (AdwSwipeTrackerClass *klass)
 
   object_class->constructed = adw_swipe_tracker_constructed;
   object_class->dispose = adw_swipe_tracker_dispose;
-  object_class->finalize = adw_swipe_tracker_finalize;
   object_class->get_property = adw_swipe_tracker_get_property;
   object_class->set_property = adw_swipe_tracker_set_property;
 
@@ -1097,7 +1087,7 @@ adw_swipe_tracker_class_init (AdwSwipeTrackerClass *klass)
 
   /**
    * AdwSwipeTracker::prepare:
-   * @self: the `AdwSwipeTracker` instance
+   * @self: a swipe tracker
    * @direction: the direction of the swipe
    *
    * This signal is emitted when a possible swipe is detected.
@@ -1119,7 +1109,6 @@ adw_swipe_tracker_class_init (AdwSwipeTrackerClass *klass)
 
   /**
    * AdwSwipeTracker::begin-swipe:
-   * @self: the `AdwSwipeTracker` instance
    *
    * This signal is emitted right before a swipe will be started, after the
    * drag threshold has been passed.
@@ -1137,7 +1126,7 @@ adw_swipe_tracker_class_init (AdwSwipeTrackerClass *klass)
 
   /**
    * AdwSwipeTracker::update-swipe:
-   * @self: the `AdwSwipeTracker` instance
+   * @self: a swipe tracker
    * @progress: the current animation progress value
    *
    * This signal is emitted every time the progress value changes.
@@ -1156,7 +1145,7 @@ adw_swipe_tracker_class_init (AdwSwipeTrackerClass *klass)
 
   /**
    * AdwSwipeTracker::end-swipe:
-   * @self: the `AdwSwipeTracker` instance
+   * @self: a swipe tracker
    * @velocity: the velocity of the swipe
    * @to: the progress value to animate to
    *
@@ -1212,7 +1201,7 @@ adw_swipe_tracker_new (AdwSwipeable *swipeable)
 
 /**
  * adw_swipe_tracker_get_swipeable: (attributes org.gtk.Method.get_property=swipeable)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  *
  * Get the widget @self is attached to.
  *
@@ -1230,7 +1219,7 @@ adw_swipe_tracker_get_swipeable (AdwSwipeTracker *self)
 
 /**
  * adw_swipe_tracker_get_enabled: (attributes org.gtk.Method.get_property=enabled)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  *
  * Gets whether @self is enabled.
  *
@@ -1248,7 +1237,7 @@ adw_swipe_tracker_get_enabled (AdwSwipeTracker *self)
 
 /**
  * adw_swipe_tracker_set_enabled: (attributes org.gtk.Method.set_property=enabled)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  * @enabled: whether @self is enabled
  *
  * Sets whether @self is enabled.
@@ -1278,7 +1267,7 @@ adw_swipe_tracker_set_enabled (AdwSwipeTracker *self,
 
 /**
  * adw_swipe_tracker_get_reversed: (attributes org.gtk.Method.get_property=reversed)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  *
  * Gets whether @self is reversing the swipe direction.
  *
@@ -1296,7 +1285,7 @@ adw_swipe_tracker_get_reversed (AdwSwipeTracker *self)
 
 /**
  * adw_swipe_tracker_set_reversed: (attributes org.gtk.Method.set_property=reversed)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  * @reversed: whether to reverse the swipe direction
  *
  * Sets whether to reverse the swipe direction.
@@ -1320,7 +1309,7 @@ adw_swipe_tracker_set_reversed (AdwSwipeTracker *self,
 
 /**
  * adw_swipe_tracker_get_allow_mouse_drag: (attributes org.gtk.Method.get_property=allow-mouse-drag)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  *
  * Gets whether @self can be dragged with mouse pointer.
  *
@@ -1338,7 +1327,7 @@ adw_swipe_tracker_get_allow_mouse_drag (AdwSwipeTracker *self)
 
 /**
  * adw_swipe_tracker_set_allow_mouse_drag: (attributes org.gtk.Method.set_property=allow-mouse-drag)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  * @allow_mouse_drag: whether to allow mouse dragging
  *
  * Sets whether @self can be dragged with mouse pointer.
@@ -1365,7 +1354,7 @@ adw_swipe_tracker_set_allow_mouse_drag (AdwSwipeTracker *self,
 
 /**
  * adw_swipe_tracker_get_allow_long_swipes: (attributes org.gtk.Method.get_property=allow-long-swipes)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  *
  * Gets whether to allow swiping for more than one snap point at a time.
  *
@@ -1383,7 +1372,7 @@ adw_swipe_tracker_get_allow_long_swipes (AdwSwipeTracker *self)
 
 /**
  * adw_swipe_tracker_set_allow_long_swipes: (attributes org.gtk.Method.set_property=allow-long-swipes)
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  * @allow_long_swipes: whether to allow long swipes
  *
  * Sets whether to allow swiping for more than one snap point at a time.
@@ -1408,7 +1397,7 @@ adw_swipe_tracker_set_allow_long_swipes (AdwSwipeTracker *self,
 
 /**
  * adw_swipe_tracker_shift_position:
- * @self: a `AdwSwipeTracker`
+ * @self: a swipe tracker
  * @delta: the position delta
  *
  * Moves the current progress value by @delta.
