@@ -102,8 +102,6 @@ struct _AdwViewSwitcherTitle
   gboolean is_window_narrow;
 
   GtkSelectionModel *pages;
-
-  guint check_window_width_id;
 };
 
 static GParamSpec *props[LAST_PROP];
@@ -226,15 +224,13 @@ check_window_width (AdwViewSwitcherTitle *self)
   self->is_window_narrow = width <= 360;
   update_view_switcher_visible (self);
 
-  self->check_window_width_id = 0;
   return G_SOURCE_REMOVE;
 }
 
 static void
 notify_surface_width_cb (AdwViewSwitcherTitle *self)
 {
-  if (self->check_window_width_id == 0)
-    self->check_window_width_id = g_idle_add (G_SOURCE_FUNC (check_window_width), self);
+  g_idle_add (G_SOURCE_FUNC (check_window_width), self);
 }
 
 static void
@@ -262,8 +258,6 @@ adw_view_switcher_title_unrealize (GtkWidget *widget)
 
   g_signal_handlers_disconnect_by_func (surface, notify_surface_width_cb, self);
 
-  g_clear_handle_id (&self->check_window_width_id, g_source_remove);
-
   GTK_WIDGET_CLASS (adw_view_switcher_title_parent_class)->unrealize (widget);
 }
 
@@ -409,7 +403,7 @@ adw_view_switcher_title_new (void)
 
 /**
  * adw_view_switcher_title_get_stack: (attributes org.gtk.Method.get_property=stack)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  *
  * Gets the stack controlled by @self.
  *
@@ -427,7 +421,7 @@ adw_view_switcher_title_get_stack (AdwViewSwitcherTitle *self)
 
 /**
  * adw_view_switcher_title_set_stack: (attributes org.gtk.Method.set_property=stack)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  * @stack: (nullable): a stack
  *
  * Sets the stack controlled by @self.
@@ -469,7 +463,7 @@ adw_view_switcher_title_set_stack (AdwViewSwitcherTitle *self,
 
 /**
  * adw_view_switcher_title_get_title: (attributes org.gtk.Method.get_property=title)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  *
  * Gets the title of @self.
  *
@@ -487,7 +481,7 @@ adw_view_switcher_title_get_title (AdwViewSwitcherTitle *self)
 
 /**
  * adw_view_switcher_title_set_title: (attributes org.gtk.Method.set_property=title)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  * @title: a title
  *
  * Sets the title of @self.
@@ -510,7 +504,7 @@ adw_view_switcher_title_set_title (AdwViewSwitcherTitle *self,
 
 /**
  * adw_view_switcher_title_get_subtitle: (attributes org.gtk.Method.get_property=subtitle)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  *
  * Gets the subtitle of @self.
  *
@@ -528,7 +522,7 @@ adw_view_switcher_title_get_subtitle (AdwViewSwitcherTitle *self)
 
 /**
  * adw_view_switcher_title_set_subtitle: (attributes org.gtk.Method.set_property=subtitle)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  * @subtitle: a subtitle
  *
  * Sets the subtitle of @self.
@@ -551,7 +545,7 @@ adw_view_switcher_title_set_subtitle (AdwViewSwitcherTitle *self,
 
 /**
  * adw_view_switcher_title_get_view_switcher_enabled: (attributes org.gtk.Method.get_property=view-switcher-enabled)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  *
  * Gets whether @self's view switcher is enabled.
  *
@@ -569,7 +563,7 @@ adw_view_switcher_title_get_view_switcher_enabled (AdwViewSwitcherTitle *self)
 
 /**
  * adw_view_switcher_title_set_view_switcher_enabled: (attributes org.gtk.Method.set_property=view-switcher-enabled)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  * @enabled: whether the view switcher is enabled
  *
  * Sets whether @self's view switcher is enabled.
@@ -595,7 +589,7 @@ adw_view_switcher_title_set_view_switcher_enabled (AdwViewSwitcherTitle *self,
 
 /**
  * adw_view_switcher_title_get_title_visible: (attributes org.gtk.Method.get_property=title-visible)
- * @self: a `AdwViewSwitcherTitle`
+ * @self: a view switcher title
  *
  * Gets whether the title of @self is currently visible.
  *
